You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@couchdb.apache.org by rn...@apache.org on 2014/07/10 16:51:23 UTC

[50/50] couchdb commit: updated refs/heads/master to 6526051

Merge branch '1843-feature-bigcouch'


Project: http://git-wip-us.apache.org/repos/asf/couchdb/repo
Commit: http://git-wip-us.apache.org/repos/asf/couchdb/commit/65260510
Tree: http://git-wip-us.apache.org/repos/asf/couchdb/tree/65260510
Diff: http://git-wip-us.apache.org/repos/asf/couchdb/diff/65260510

Branch: refs/heads/master
Commit: 65260510eff0479ac9d1cb8e68e9aa8619f39d1b
Parents: ade9dae 86f68c9
Author: Robert Newson <rn...@apache.org>
Authored: Thu Jul 10 15:28:53 2014 +0100
Committer: Robert Newson <rn...@apache.org>
Committed: Thu Jul 10 15:49:00 2014 +0100

----------------------------------------------------------------------
 .gitignore                                      |   158 +-
 .travis.yml                                     |     2 +-
 Dockerfile                                      |    33 +
 LICENSE                                         |     4 +-
 Makefile                                        |    58 +
 Makefile.am                                     |   155 -
 TODO                                            |    10 +
 acinclude.m4.in                                 |    30 -
 bin/Makefile.am                                 |   159 -
 bin/couch-config.tpl.in                         |   140 -
 bin/couchdb.bat.tpl.in                          |    26 -
 bin/couchdb.tpl.in                              |   385 -
 bootstrap                                       |   151 -
 configure                                       |   138 +
 configure.ac                                    |   799 -
 dev/boot_node.erl                               |   136 +
 dev/remsh                                       |    29 +
 dev/run                                         |   263 +
 etc/Makefile.am                                 |   117 -
 etc/couchdb/Makefile.am                         |    95 -
 etc/couchdb/default.ini.tpl.in                  |   364 -
 etc/couchdb/local.ini                           |   108 -
 etc/default/Makefile.am                         |    13 -
 etc/default/couchdb                             |     7 -
 etc/init/Makefile.am                            |    13 -
 etc/init/couchdb.tpl.in                         |   159 -
 etc/launchd/Makefile.am                         |    13 -
 etc/launchd/org.apache.couchdb.plist.tpl.in     |    30 -
 etc/logrotate.d/Makefile.am                     |    13 -
 etc/logrotate.d/couchdb.tpl.in                  |     9 -
 etc/windows/Makefile.am                         |    13 -
 etc/windows/README.txt.tpl                      |    29 -
 etc/windows/couchdb.iss.tpl                     |    92 -
 license.skip                                    |    75 +-
 rebar.config.script                             |    60 +
 rel/boot_dev_cluster.sh                         |    40 +
 rel/files/README                                |    16 +
 rel/files/sys.config                            |    13 +
 rel/files/vm.args                               |    11 +
 rel/haproxy.cfg                                 |    45 +
 rel/overlay/bin/couchdb                         |    28 +
 rel/overlay/etc/default.ini                     |   373 +
 rel/overlay/etc/local.ini                       |    98 +
 rel/overlay/etc/vm.args                         |    35 +
 rel/reltool.config                              |    92 +
 share/Makefile.am                               |   260 -
 share/doc/Makefile.am                           |    14 -
 share/doc/build/Makefile.am                     |   630 -
 share/server/loop.js                            |     2 +-
 share/server/util.js                            |     9 +-
 share/server/views.js                           |    12 +-
 share/www/script/couch.js                       |     8 +-
 share/www/script/couch_test_runner.js           |    55 +-
 share/www/script/futon.browse.js                |     4 +-
 share/www/script/test/erlang_views.js           |     5 +-
 share/www/script/test/oauth.js                  |     3 +-
 share/www/script/test/proxyauth.js              |     7 +-
 share/www/script/test/replication.js            |    20 +-
 share/www/script/test/security_validation.js    |     2 +
 share/www/script/test/show_documents.js         |     2 +-
 share/www/script/test/users_db_security.js      |     1 -
 share/www/script/test/view_compaction.js        |    26 +-
 share/www/script/test/view_include_docs.js      |     2 +-
 share/www/script/test/view_update_seq.js        |    10 +-
 src/Makefile.am                                 |   345 -
 src/couch_dbupdates/Makefile.am                 |    33 -
 src/couch_dbupdates/src/couch_dbupdates.app.src |    11 -
 src/couch_dbupdates/src/couch_dbupdates.erl     |    46 -
 .../src/couch_dbupdates_httpd.erl               |    69 -
 src/couch_index/Makefile.am                     |    40 -
 src/couch_index/src/couch_index.app.src         |    22 -
 src/couch_index/src/couch_index.erl             |   340 -
 src/couch_index/src/couch_index_api.erl         |    54 -
 src/couch_index/src/couch_index_compactor.erl   |   114 -
 src/couch_index/src/couch_index_server.erl      |   201 -
 src/couch_index/src/couch_index_updater.erl     |   200 -
 src/couch_index/src/couch_index_util.erl        |    78 -
 src/couch_mrview/Makefile.am                    |    73 -
 src/couch_mrview/include/couch_mrview.hrl       |    81 -
 src/couch_mrview/src/couch_mrview.app.src       |    28 -
 src/couch_mrview/src/couch_mrview.erl           |   387 -
 src/couch_mrview/src/couch_mrview_cleanup.erl   |    47 -
 src/couch_mrview/src/couch_mrview_compactor.erl |   178 -
 src/couch_mrview/src/couch_mrview_http.erl      |   410 -
 src/couch_mrview/src/couch_mrview_index.erl     |   162 -
 src/couch_mrview/src/couch_mrview_show.erl      |   368 -
 src/couch_mrview/src/couch_mrview_test_util.erl |    91 -
 src/couch_mrview/src/couch_mrview_updater.erl   |   282 -
 src/couch_mrview/src/couch_mrview_util.erl      |   797 -
 src/couch_mrview/test/01-load.t                 |    34 -
 src/couch_mrview/test/02-map-views.t            |   131 -
 src/couch_mrview/test/03-red-views.t            |    78 -
 src/couch_mrview/test/04-index-info.t           |    54 -
 src/couch_mrview/test/05-collation.t            |   163 -
 src/couch_mrview/test/06-all-docs.t             |   127 -
 src/couch_mrview/test/07-compact-swap.t         |    57 -
 src/couch_plugins/Makefile.am                   |    40 -
 src/couch_plugins/README.md                     |   159 -
 src/couch_plugins/src/couch_plugins.app.src     |    23 -
 src/couch_plugins/src/couch_plugins.erl         |   300 -
 src/couch_plugins/src/couch_plugins_httpd.erl   |    65 -
 src/couch_replicator/Makefile.am                |    78 -
 .../src/couch_replicator.app.src                |    33 -
 src/couch_replicator/src/couch_replicator.erl   |   965 -
 src/couch_replicator/src/couch_replicator.hrl   |    30 -
 .../src/couch_replicator_api_wrap.erl           |   895 -
 .../src/couch_replicator_api_wrap.hrl           |    36 -
 .../src/couch_replicator_httpc.erl              |   297 -
 .../src/couch_replicator_httpc_pool.erl         |   138 -
 .../src/couch_replicator_httpd.erl              |    66 -
 .../src/couch_replicator_job_sup.erl            |    31 -
 .../src/couch_replicator_js_functions.hrl       |   151 -
 .../src/couch_replicator_manager.erl            |   709 -
 .../src/couch_replicator_notifier.erl           |    57 -
 .../src/couch_replicator_utils.erl              |   397 -
 .../src/couch_replicator_worker.erl             |   515 -
 src/couch_replicator/test/01-load.t             |    37 -
 src/couch_replicator/test/02-httpc-pool.t       |   250 -
 .../test/03-replication-compact.t               |   488 -
 .../test/04-replication-large-atts.t            |   267 -
 .../test/05-replication-many-leaves.t           |   294 -
 .../test/06-doc-missing-stubs.t                 |   304 -
 src/couch_replicator/test/07-use-checkpoints.t  |   273 -
 src/couchdb/Makefile.am                         |   198 -
 src/couchdb/couch.app.tpl.in                    |    27 -
 src/couchdb/couch.erl                           |    39 -
 src/couchdb/couch_app.erl                       |    56 -
 src/couchdb/couch_auth_cache.erl                |   425 -
 src/couchdb/couch_btree.erl                     |   714 -
 src/couchdb/couch_changes.erl                   |   577 -
 src/couchdb/couch_compaction_daemon.erl         |   504 -
 src/couchdb/couch_compress.erl                  |    84 -
 src/couchdb/couch_config.erl                    |   251 -
 src/couchdb/couch_config_writer.erl             |    88 -
 src/couchdb/couch_db.erl                        |  1358 --
 src/couchdb/couch_db.hrl                        |   286 -
 src/couchdb/couch_db_update_notifier.erl        |    82 -
 src/couchdb/couch_db_update_notifier_sup.erl    |    61 -
 src/couchdb/couch_db_updater.erl                |  1040 --
 src/couchdb/couch_doc.erl                       |   650 -
 src/couchdb/couch_drv.erl                       |    62 -
 src/couchdb/couch_ejson_compare.erl             |   113 -
 src/couchdb/couch_event_sup.erl                 |    73 -
 src/couchdb/couch_external_manager.erl          |   101 -
 src/couchdb/couch_external_server.erl           |    70 -
 src/couchdb/couch_file.erl                      |   532 -
 src/couchdb/couch_httpd.erl                     |  1107 --
 src/couchdb/couch_httpd_auth.erl                |   416 -
 src/couchdb/couch_httpd_cors.erl                |   351 -
 src/couchdb/couch_httpd_db.erl                  |  1228 --
 src/couchdb/couch_httpd_external.erl            |   177 -
 src/couchdb/couch_httpd_misc_handlers.erl       |   333 -
 src/couchdb/couch_httpd_oauth.erl               |   388 -
 src/couchdb/couch_httpd_proxy.erl               |   426 -
 src/couchdb/couch_httpd_rewrite.erl             |   480 -
 src/couchdb/couch_httpd_stats_handlers.erl      |    56 -
 src/couchdb/couch_httpd_vhost.erl               |   383 -
 src/couchdb/couch_js_functions.hrl              |   170 -
 src/couchdb/couch_key_tree.erl                  |   422 -
 src/couchdb/couch_log.erl                       |   254 -
 src/couchdb/couch_native_process.erl            |   409 -
 src/couchdb/couch_os_daemons.erl                |   374 -
 src/couchdb/couch_os_process.erl                |   216 -
 src/couchdb/couch_passwords.erl                 |   128 -
 src/couchdb/couch_primary_sup.erl               |    66 -
 src/couchdb/couch_query_servers.erl             |   616 -
 src/couchdb/couch_ref_counter.erl               |   111 -
 src/couchdb/couch_secondary_sup.erl             |    49 -
 src/couchdb/couch_server.erl                    |   499 -
 src/couchdb/couch_server_sup.erl                |   164 -
 src/couchdb/couch_stats_aggregator.erl          |   297 -
 src/couchdb/couch_stats_collector.erl           |   136 -
 src/couchdb/couch_stream.erl                    |   299 -
 src/couchdb/couch_task_status.erl               |   151 -
 src/couchdb/couch_users_db.erl                  |   121 -
 src/couchdb/couch_util.erl                      |   521 -
 src/couchdb/couch_uuids.erl                     |   103 -
 src/couchdb/couch_work_queue.erl                |   187 -
 src/couchdb/json_stream_parse.erl               |   432 -
 src/couchdb/priv/Makefile.am                    |   153 -
 .../couch_ejson_compare/couch_ejson_compare.c   |   457 -
 .../priv/couch_ejson_compare/erl_nif_compat.h   |   128 -
 src/couchdb/priv/couch_js/help.h                |    82 -
 src/couchdb/priv/couch_js/http.c                |   698 -
 src/couchdb/priv/couch_js/http.h                |    27 -
 src/couchdb/priv/couch_js/main.c                |    21 -
 src/couchdb/priv/couch_js/sm170.c               |   398 -
 src/couchdb/priv/couch_js/sm180.c               |   407 -
 src/couchdb/priv/couch_js/sm185.c               |   431 -
 src/couchdb/priv/couch_js/utf8.c                |   294 -
 src/couchdb/priv/couch_js/utf8.h                |    19 -
 src/couchdb/priv/couch_js/util.c                |   294 -
 src/couchdb/priv/couch_js/util.h                |    35 -
 src/couchdb/priv/icu_driver/couch_icu_driver.c  |   189 -
 .../priv/spawnkillable/couchspawnkillable.sh    |    20 -
 .../priv/spawnkillable/couchspawnkillable_win.c |   145 -
 src/couchdb/priv/stat_descriptions.cfg.in       |    50 -
 src/couchjs-node/Makefile.am                    |    24 -
 src/couchjs-node/README.md                      |    32 -
 src/couchjs-node/cli.js                         |    89 -
 src/couchjs-node/console.js                     |    66 -
 src/couchjs-node/couchdb.js                     |    29 -
 src/couchjs-node/couchjs.js                     |   133 -
 src/couchjs-node/inspector.js                   |   101 -
 src/couchjs-node/package.json                   |    40 -
 src/couchjs-node/sandbox.js                     |    47 -
 src/couchjs-node/stream.js                      |   115 -
 src/couchjs-node/test/experiment.js             |   125 -
 src/couchjs-node/xml.js                         |    22 -
 src/ejson/Makefile.am                           |    91 -
 src/ejson/decode.c                              |   308 -
 src/ejson/ejson.app.in                          |     9 -
 src/ejson/ejson.c                               |    30 -
 src/ejson/ejson.erl                             |   168 -
 src/ejson/encode.c                              |   200 -
 src/ejson/erl_nif_compat.h                      |   120 -
 src/ejson/mochijson2.erl                        |   849 -
 src/ejson/mochinum.erl                          |   354 -
 src/ejson/yajl/yajl.c                           |   159 -
 src/ejson/yajl/yajl_alloc.c                     |    65 -
 src/ejson/yajl/yajl_alloc.h                     |    50 -
 src/ejson/yajl/yajl_buf.c                       |   119 -
 src/ejson/yajl/yajl_buf.h                       |    73 -
 src/ejson/yajl/yajl_bytestack.h                 |    85 -
 src/ejson/yajl/yajl_common.h                    |    85 -
 src/ejson/yajl/yajl_encode.c                    |   195 -
 src/ejson/yajl/yajl_encode.h                    |    50 -
 src/ejson/yajl/yajl_gen.c                       |   322 -
 src/ejson/yajl/yajl_gen.h                       |   159 -
 src/ejson/yajl/yajl_lex.c                       |   737 -
 src/ejson/yajl/yajl_lex.h                       |   133 -
 src/ejson/yajl/yajl_parse.h                     |   193 -
 src/ejson/yajl/yajl_parser.c                    |   470 -
 src/ejson/yajl/yajl_parser.h                    |    95 -
 src/erlang-oauth/Makefile.am                    |    39 -
 src/erlang-oauth/oauth.app.in                   |    20 -
 src/erlang-oauth/oauth.erl                      |   315 -
 src/etap/Makefile.am                            |    28 -
 src/etap/etap.erl                               |   614 -
 src/fauxton/CONTRIBUTING.md                     |    22 -
 src/fauxton/Gruntfile.js                        |   476 -
 .../activetasks/assets/less/activetasks.less    |    16 -
 src/fauxton/app/addons/activetasks/base.js      |    26 -
 src/fauxton/app/addons/activetasks/resources.js |    68 -
 src/fauxton/app/addons/activetasks/routes.js    |    59 -
 .../app/addons/activetasks/templates/table.html |    52 -
 .../activetasks/templates/tabledetail.html      |    32 -
 .../app/addons/activetasks/templates/tabs.html  |    46 -
 .../app/addons/activetasks/tests/viewsSpec.js   |   126 -
 src/fauxton/app/addons/activetasks/views.js     |   210 -
 .../app/addons/auth/assets/less/auth.less       |    15 -
 src/fauxton/app/addons/auth/base.js             |    73 -
 src/fauxton/app/addons/auth/resources.js        |   384 -
 src/fauxton/app/addons/auth/routes.js           |   102 -
 .../addons/auth/templates/change_password.html  |    26 -
 .../app/addons/auth/templates/create_admin.html |    36 -
 .../app/addons/auth/templates/login.html        |    26 -
 .../app/addons/auth/templates/nav_dropdown.html |    26 -
 .../addons/auth/templates/nav_link_title.html   |    32 -
 .../app/addons/auth/templates/noAccess.html     |    22 -
 src/fauxton/app/addons/auth/test/baseSpec.js    |    34 -
 .../compaction/assets/less/compaction.less      |    19 -
 src/fauxton/app/addons/compaction/base.js       |    31 -
 src/fauxton/app/addons/compaction/resources.js  |    48 -
 src/fauxton/app/addons/compaction/routes.js     |    65 -
 .../compaction/templates/compact_view.html      |    14 -
 .../app/addons/compaction/templates/layout.html |    28 -
 src/fauxton/app/addons/compaction/views.js      |   142 -
 .../app/addons/config/assets/less/config.less   |    47 -
 src/fauxton/app/addons/config/base.js           |    30 -
 src/fauxton/app/addons/config/resources.js      |    83 -
 src/fauxton/app/addons/config/routes.js         |    59 -
 .../app/addons/config/templates/dashboard.html  |    31 -
 .../app/addons/config/templates/item.html       |    40 -
 .../app/addons/config/templates/modal.html      |    33 -
 .../app/addons/config/tests/resourcesSpec.js    |    97 -
 src/fauxton/app/addons/config/views.js          |   248 -
 src/fauxton/app/addons/contribute/base.js       |    33 -
 .../addons/databases/assets/less/databases.less |    34 -
 src/fauxton/app/addons/databases/base.js        |    37 -
 src/fauxton/app/addons/databases/resources.js   |   189 -
 src/fauxton/app/addons/databases/routes.js      |    69 -
 .../app/addons/databases/templates/item.html    |    30 -
 .../app/addons/databases/templates/list.html    |    37 -
 .../addons/databases/templates/newdatabase.html |    16 -
 .../app/addons/databases/tests/resourcesSpec.js |    39 -
 src/fauxton/app/addons/databases/views.js       |   196 -
 .../addons/documents/assets/less/documents.less |   155 -
 src/fauxton/app/addons/documents/base.js        |    24 -
 src/fauxton/app/addons/documents/resources.js   |   703 -
 src/fauxton/app/addons/documents/routes.js      |   492 -
 .../documents/templates/advanced_options.html   |   157 -
 .../documents/templates/all_docs_item.html      |    26 -
 .../documents/templates/all_docs_layout.html    |    21 -
 .../documents/templates/all_docs_list.html      |    44 -
 .../documents/templates/all_docs_number.html    |    35 -
 .../app/addons/documents/templates/changes.html |    68 -
 .../addons/documents/templates/code_editor.html |    55 -
 .../addons/documents/templates/ddoc_info.html   |    28 -
 .../templates/delete_database_modal.html        |    39 -
 .../templates/design_doc_selector.html          |    35 -
 .../templates/duplicate_doc_modal.html          |    36 -
 .../addons/documents/templates/edit_tools.html  |    44 -
 .../documents/templates/index_menu_item.html    |    17 -
 .../documents/templates/index_row_docular.html  |    29 -
 .../documents/templates/index_row_tabular.html  |    25 -
 .../app/addons/documents/templates/jumpdoc.html |    20 -
 .../app/addons/documents/templates/search.html  |    15 -
 .../app/addons/documents/templates/sidebar.html |    68 -
 .../documents/templates/upload_modal.html       |    42 -
 .../addons/documents/templates/view_editor.html |    90 -
 .../app/addons/documents/tests/resourcesSpec.js |   227 -
 .../app/addons/documents/tests/viewsSpec.js     |    23 -
 src/fauxton/app/addons/documents/views.js       |  2009 --
 src/fauxton/app/addons/exampleAuth/base.js      |    59 -
 .../addons/exampleAuth/templates/noAccess.html  |    19 -
 src/fauxton/app/addons/fauxton/base.js          |   350 -
 src/fauxton/app/addons/fauxton/components.js    |   617 -
 src/fauxton/app/addons/fauxton/resizeColumns.js |    91 -
 .../app/addons/fauxton/templates/api_bar.html   |    30 -
 .../addons/fauxton/templates/breadcrumbs.html   |    24 -
 .../app/addons/fauxton/templates/filter.html    |    22 -
 .../addons/fauxton/templates/filter_item.html   |    16 -
 .../app/addons/fauxton/templates/footer.html    |    15 -
 .../fauxton/templates/index_pagination.html     |    24 -
 .../app/addons/fauxton/templates/nav_bar.html   |    74 -
 .../addons/fauxton/templates/notification.html  |    18 -
 .../addons/fauxton/templates/pagination.html    |    31 -
 .../app/addons/fauxton/tests/baseSpec.js        |   116 -
 .../app/addons/fauxton/tests/filterViewSpec.js  |    87 -
 .../app/addons/fauxton/tests/navbarSpec.js      |   107 -
 .../app/addons/fauxton/tests/paginateSpec.js    |    87 -
 .../permissions/assets/less/permissions.less    |    27 -
 src/fauxton/app/addons/permissions/base.js      |    25 -
 src/fauxton/app/addons/permissions/resources.js |    70 -
 src/fauxton/app/addons/permissions/routes.js    |    63 -
 .../app/addons/permissions/templates/item.html  |    17 -
 .../permissions/templates/permissions.html      |    15 -
 .../addons/permissions/templates/section.html   |    46 -
 .../addons/permissions/tests/resourceSpec.js    |    51 -
 .../app/addons/permissions/tests/viewsSpec.js   |   163 -
 src/fauxton/app/addons/permissions/views.js     |   200 -
 src/fauxton/app/addons/plugins/base.js          |    24 -
 src/fauxton/app/addons/plugins/resources.js     |    26 -
 src/fauxton/app/addons/plugins/routes.js        |    47 -
 .../app/addons/plugins/templates/plugins.html   |   102 -
 src/fauxton/app/addons/pouchdb/base.js          |    58 -
 src/fauxton/app/addons/pouchdb/pouch.collate.js |   115 -
 .../app/addons/pouchdb/pouchdb.mapreduce.js     |   324 -
 .../replication/assets/less/replication.less    |   188 -
 src/fauxton/app/addons/replication/base.js      |    24 -
 src/fauxton/app/addons/replication/resources.js |    69 -
 src/fauxton/app/addons/replication/route.js     |    50 -
 .../app/addons/replication/templates/form.html  |    74 -
 .../addons/replication/templates/progress.html  |    22 -
 .../addons/replication/tests/replicationSpec.js |    28 -
 src/fauxton/app/addons/replication/views.js     |   297 -
 .../app/addons/stats/assets/less/stats.less     |    20 -
 src/fauxton/app/addons/stats/base.js            |    26 -
 src/fauxton/app/addons/stats/resources.js       |    38 -
 src/fauxton/app/addons/stats/routes.js          |    62 -
 .../app/addons/stats/templates/by_method.html   |    16 -
 .../app/addons/stats/templates/pie_table.html   |    54 -
 .../app/addons/stats/templates/stats.html       |    16 -
 .../app/addons/stats/templates/statselect.html  |    22 -
 src/fauxton/app/addons/stats/views.js           |   170 -
 src/fauxton/app/addons/styletests/base.js       |    33 -
 src/fauxton/app/addons/styletests/resources.js  |    22 -
 src/fauxton/app/addons/styletests/routes.js     |    40 -
 .../app/addons/styletests/templates/theme.html  |   497 -
 src/fauxton/app/addons/styletests/views.js      |    29 -
 .../assets/less/verifyinstall.less              |    16 -
 src/fauxton/app/addons/verifyinstall/base.js    |    31 -
 .../app/addons/verifyinstall/resources.js       |   176 -
 src/fauxton/app/addons/verifyinstall/routes.js  |    37 -
 .../addons/verifyinstall/templates/main.html    |    50 -
 src/fauxton/app/addons/verifyinstall/views.js   |   127 -
 src/fauxton/app/app.js                          |   111 -
 src/fauxton/app/config.js                       |    64 -
 src/fauxton/app/core/api.js                     |    53 -
 src/fauxton/app/core/auth.js                    |    65 -
 src/fauxton/app/core/base.js                    |   145 -
 src/fauxton/app/core/couchdbSession.js          |    60 -
 src/fauxton/app/core/layout.js                  |    91 -
 src/fauxton/app/core/routeObject.js             |   297 -
 src/fauxton/app/core/router.js                  |   113 -
 src/fauxton/app/core/tests/layoutSpec.js        |    92 -
 src/fauxton/app/core/tests/routeObjectSpec.js   |    96 -
 src/fauxton/app/core/utils.js                   |    94 -
 src/fauxton/app/helpers.js                      |    84 -
 src/fauxton/app/initialize.js.underscore        |    33 -
 src/fauxton/app/load_addons.js.underscore       |    27 -
 src/fauxton/app/main.js                         |    47 -
 src/fauxton/app/templates/layouts/one_pane.html |    28 -
 src/fauxton/app/templates/layouts/two_pane.html |    30 -
 .../app/templates/layouts/with_sidebar.html     |    27 -
 .../app/templates/layouts/with_tabs.html        |    27 -
 .../templates/layouts/with_tabs_sidebar.html    |    39 -
 src/fauxton/assets/css/nv.d3.css                |   769 -
 src/fauxton/assets/img/FontAwesome.otf          |   Bin 61896 -> 0 bytes
 src/fauxton/assets/img/couchdb-site.png         |   Bin 4946 -> 0 bytes
 src/fauxton/assets/img/couchdblogo.png          |   Bin 2738 -> 0 bytes
 src/fauxton/assets/img/fontawesome-webfont.eot  |   Bin 37405 -> 0 bytes
 src/fauxton/assets/img/fontawesome-webfont.svg  |   399 -
 src/fauxton/assets/img/fontawesome-webfont.ttf  |   Bin 79076 -> 0 bytes
 src/fauxton/assets/img/fontawesome-webfont.woff |   Bin 43572 -> 0 bytes
 src/fauxton/assets/img/fontcustom_fauxton.eot   |   Bin 7364 -> 0 bytes
 src/fauxton/assets/img/fontcustom_fauxton.svg   |   200 -
 src/fauxton/assets/img/fontcustom_fauxton.ttf   |   Bin 9636 -> 0 bytes
 src/fauxton/assets/img/fontcustom_fauxton.woff  |   Bin 4816 -> 0 bytes
 .../assets/img/glyphicons-halflings-white.png   |   Bin 8777 -> 0 bytes
 src/fauxton/assets/img/glyphicons-halflings.png |   Bin 13826 -> 0 bytes
 src/fauxton/assets/img/linen.png                |   Bin 87134 -> 0 bytes
 src/fauxton/assets/img/loader.gif               |   Bin 5193 -> 0 bytes
 src/fauxton/assets/img/minilogo.png             |   Bin 2927 -> 0 bytes
 src/fauxton/assets/index.underscore             |    47 -
 src/fauxton/assets/js/libs/ace/ace.js           | 16541 -----------------
 src/fauxton/assets/js/libs/ace/ext-chromevox.js |   537 -
 .../js/libs/ace/ext-elastic_tabstops_lite.js    |   301 -
 src/fauxton/assets/js/libs/ace/ext-emmet.js     |  1096 --
 .../assets/js/libs/ace/ext-keybinding_menu.js   |   207 -
 .../assets/js/libs/ace/ext-language_tools.js    |  1615 --
 src/fauxton/assets/js/libs/ace/ext-modelist.js  |   166 -
 src/fauxton/assets/js/libs/ace/ext-old_ie.js    |   499 -
 src/fauxton/assets/js/libs/ace/ext-options.js   |   252 -
 src/fauxton/assets/js/libs/ace/ext-searchbox.js |   420 -
 .../assets/js/libs/ace/ext-settings_menu.js     |   634 -
 .../assets/js/libs/ace/ext-spellcheck.js        |    68 -
 src/fauxton/assets/js/libs/ace/ext-split.js     |   271 -
 .../assets/js/libs/ace/ext-static_highlight.js  |   165 -
 src/fauxton/assets/js/libs/ace/ext-statusbar.js |    47 -
 src/fauxton/assets/js/libs/ace/ext-textarea.js  |   478 -
 src/fauxton/assets/js/libs/ace/ext-themelist.js |    90 -
 .../assets/js/libs/ace/ext-whitespace.js        |   206 -
 .../assets/js/libs/ace/mode-javascript.js       |   886 -
 src/fauxton/assets/js/libs/ace/mode-json.js     |   578 -
 src/fauxton/assets/js/libs/ace/mode-jsoniq.js   |  2714 ---
 .../assets/js/libs/ace/snippets/javascript.js   |   202 -
 src/fauxton/assets/js/libs/ace/snippets/json.js |     7 -
 .../assets/js/libs/ace/snippets/jsoniq.js       |     7 -
 .../assets/js/libs/ace/theme-crimson_editor.js  |   148 -
 .../assets/js/libs/ace/worker-javascript.js     | 10088 ----------
 src/fauxton/assets/js/libs/ace/worker-json.js   |  2271 ---
 src/fauxton/assets/js/libs/almond.js            |   314 -
 src/fauxton/assets/js/libs/backbone.js          |  1583 --
 src/fauxton/assets/js/libs/bootstrap.js         |  2291 ---
 src/fauxton/assets/js/libs/d3.js                |  9275 ---------
 src/fauxton/assets/js/libs/jquery.js            | 10337 ----------
 src/fauxton/assets/js/libs/lodash.js            |  4493 -----
 src/fauxton/assets/js/libs/nv.d3.js             | 14374 --------------
 src/fauxton/assets/js/libs/require.js           |  2045 --
 src/fauxton/assets/js/libs/spin.min.js          |     1 -
 .../assets/js/plugins/backbone.layoutmanager.js |   976 -
 src/fauxton/assets/js/plugins/beautify.js       |  1630 --
 .../js/plugins/cloudant.pagingcollection.js     |   224 -
 src/fauxton/assets/js/plugins/jquery.form.js    |  1190 --
 src/fauxton/assets/js/plugins/prettify.js       |    28 -
 .../js/plugins/zeroclipboard/ZeroClipboard.js   |  1031 -
 .../js/plugins/zeroclipboard/ZeroClipboard.swf  |   Bin 2157 -> 0 bytes
 .../assets/less/bootstrap/accordion.less        |    34 -
 src/fauxton/assets/less/bootstrap/alerts.less   |    79 -
 .../assets/less/bootstrap/bootstrap.less        |    62 -
 .../assets/less/bootstrap/breadcrumbs.less      |    24 -
 .../assets/less/bootstrap/button-groups.less    |   229 -
 src/fauxton/assets/less/bootstrap/buttons.less  |   228 -
 src/fauxton/assets/less/bootstrap/carousel.less |   158 -
 src/fauxton/assets/less/bootstrap/close.less    |    32 -
 src/fauxton/assets/less/bootstrap/code.less     |    61 -
 .../less/bootstrap/component-animations.less    |    22 -
 .../assets/less/bootstrap/dropdowns.less        |   248 -
 .../less/bootstrap/font-awesome/bootstrap.less  |    84 -
 .../less/bootstrap/font-awesome/core.less       |   129 -
 .../less/bootstrap/font-awesome/extras.less     |    93 -
 .../font-awesome/font-awesome-ie7.less          |  1953 --
 .../bootstrap/font-awesome/font-awesome.less    |    33 -
 .../less/bootstrap/font-awesome/icons.less      |   381 -
 .../less/bootstrap/font-awesome/mixins.less     |    48 -
 .../less/bootstrap/font-awesome/path.less       |    14 -
 .../less/bootstrap/font-awesome/variables.less  |   735 -
 src/fauxton/assets/less/bootstrap/forms.less    |   690 -
 src/fauxton/assets/less/bootstrap/grid.less     |    21 -
 .../assets/less/bootstrap/hero-unit.less        |    25 -
 .../assets/less/bootstrap/labels-badges.less    |    84 -
 src/fauxton/assets/less/bootstrap/layouts.less  |    16 -
 src/fauxton/assets/less/bootstrap/media.less    |    55 -
 src/fauxton/assets/less/bootstrap/mixins.less   |   716 -
 src/fauxton/assets/less/bootstrap/modals.less   |    95 -
 src/fauxton/assets/less/bootstrap/navbar.less   |   497 -
 src/fauxton/assets/less/bootstrap/navs.less     |   409 -
 src/fauxton/assets/less/bootstrap/pager.less    |    43 -
 .../assets/less/bootstrap/pagination.less       |   123 -
 src/fauxton/assets/less/bootstrap/popovers.less |   133 -
 .../assets/less/bootstrap/progress-bars.less    |   122 -
 src/fauxton/assets/less/bootstrap/reset.less    |   216 -
 .../less/bootstrap/responsive-1200px-min.less   |    28 -
 .../less/bootstrap/responsive-767px-max.less    |   193 -
 .../less/bootstrap/responsive-768px-979px.less  |    19 -
 .../less/bootstrap/responsive-navbar.less       |   189 -
 .../less/bootstrap/responsive-utilities.less    |    59 -
 .../assets/less/bootstrap/responsive.less       |    48 -
 .../assets/less/bootstrap/scaffolding.less      |    53 -
 src/fauxton/assets/less/bootstrap/sprites.less  |   197 -
 src/fauxton/assets/less/bootstrap/tables.less   |   244 -
 .../assets/less/bootstrap/tests/buttons.html    |   139 -
 .../assets/less/bootstrap/tests/css-tests.css   |   150 -
 .../assets/less/bootstrap/thumbnails.less       |    53 -
 src/fauxton/assets/less/bootstrap/tooltip.less  |    70 -
 src/fauxton/assets/less/bootstrap/type.less     |   247 -
 .../assets/less/bootstrap/utilities.less        |    30 -
 .../assets/less/bootstrap/variables.less        |   301 -
 src/fauxton/assets/less/bootstrap/wells.less    |    29 -
 src/fauxton/assets/less/couchdb.less            |    72 -
 src/fauxton/assets/less/fauxton.less            |   915 -
 src/fauxton/assets/less/icons.less              |   111 -
 src/fauxton/assets/less/prettyprint.less        |    35 -
 src/fauxton/assets/less/variables.less          |    84 -
 src/fauxton/bin/grunt                           |    18 -
 src/fauxton/couchapp.js                         |    39 -
 src/fauxton/extensions.md                       |    17 -
 src/fauxton/favicon.ico                         |   Bin 1150 -> 0 bytes
 src/fauxton/index.html                          |    53 -
 src/fauxton/package.json                        |    48 -
 src/fauxton/readme.md                           |    69 -
 src/fauxton/settings.json.default               |    76 -
 src/fauxton/settings.json.sample_external       |    10 -
 src/fauxton/tasks/addon/rename.json             |     5 -
 src/fauxton/tasks/addon/root/base.js.underscore |    21 -
 .../tasks/addon/root/resources.js.underscore    |    21 -
 .../tasks/addon/root/routes.js.underscore       |    42 -
 src/fauxton/tasks/addon/template.js             |    70 -
 src/fauxton/tasks/couchserver.js                |   133 -
 src/fauxton/tasks/fauxton.js                    |   136 -
 src/fauxton/tasks/helper.js                     |    45 -
 src/fauxton/test/mocha/chai.js                  |  4696 -----
 src/fauxton/test/mocha/mocha.css                |   251 -
 src/fauxton/test/mocha/mocha.js                 |  5428 ------
 src/fauxton/test/mocha/sinon-chai.js            |   109 -
 src/fauxton/test/mocha/sinon.js                 |  4290 -----
 src/fauxton/test/mocha/testUtils.js             |    51 -
 src/fauxton/test/runner.html                    |    33 -
 src/fauxton/test/test.config.underscore         |    20 -
 src/fauxton/writing_addons.md                   |   173 -
 src/ibrowse/Makefile.am                         |    51 -
 src/ibrowse/ibrowse.app.in                      |     7 -
 src/ibrowse/ibrowse.erl                         |   929 -
 src/ibrowse/ibrowse.hrl                         |    21 -
 src/ibrowse/ibrowse_app.erl                     |    63 -
 src/ibrowse/ibrowse_http_client.erl             |  1945 --
 src/ibrowse/ibrowse_lb.erl                      |   252 -
 src/ibrowse/ibrowse_lib.erl                     |   442 -
 src/ibrowse/ibrowse_socks5.erl                  |   109 -
 src/ibrowse/ibrowse_sup.erl                     |    63 -
 src/ibrowse/ibrowse_test.erl                    |   625 -
 src/mochiweb/Makefile.am                        |   109 -
 src/mochiweb/internal.hrl                       |     3 -
 src/mochiweb/mochifmt.erl                       |   425 -
 src/mochiweb/mochifmt_records.erl               |    42 -
 src/mochiweb/mochifmt_std.erl                   |    33 -
 src/mochiweb/mochiglobal.erl                    |   107 -
 src/mochiweb/mochihex.erl                       |    88 -
 src/mochiweb/mochijson.erl                      |   529 -
 src/mochiweb/mochijson2.erl                     |   889 -
 src/mochiweb/mochilists.erl                     |   104 -
 src/mochiweb/mochilogfile2.erl                  |   140 -
 src/mochiweb/mochinum.erl                       |   354 -
 src/mochiweb/mochitemp.erl                      |   311 -
 src/mochiweb/mochiutf8.erl                      |   317 -
 src/mochiweb/mochiweb.app.in                    |     9 -
 src/mochiweb/mochiweb.erl                       |   281 -
 src/mochiweb/mochiweb_acceptor.erl              |    51 -
 src/mochiweb/mochiweb_app.erl                   |    27 -
 src/mochiweb/mochiweb_charref.erl               |  2183 ---
 src/mochiweb/mochiweb_cookies.erl               |   331 -
 src/mochiweb/mochiweb_cover.erl                 |    75 -
 src/mochiweb/mochiweb_echo.erl                  |    41 -
 src/mochiweb/mochiweb_headers.erl               |   420 -
 src/mochiweb/mochiweb_html.erl                  |  1332 --
 src/mochiweb/mochiweb_http.erl                  |   264 -
 src/mochiweb/mochiweb_io.erl                    |    43 -
 src/mochiweb/mochiweb_mime.erl                  |   415 -
 src/mochiweb/mochiweb_multipart.erl             |   872 -
 src/mochiweb/mochiweb_request.erl               |   876 -
 src/mochiweb/mochiweb_request_tests.erl         |   182 -
 src/mochiweb/mochiweb_response.erl              |    72 -
 src/mochiweb/mochiweb_skel.erl                  |    86 -
 src/mochiweb/mochiweb_socket.erl                |    83 -
 src/mochiweb/mochiweb_socket_server.erl         |   350 -
 src/mochiweb/mochiweb_sup.erl                   |    41 -
 src/mochiweb/mochiweb_util.erl                  |   986 -
 src/mochiweb/reloader.erl                       |   161 -
 src/my-first-couchdb-plugin/.gitignore          |     1 -
 src/my-first-couchdb-plugin/Makefile            |    38 -
 src/my-first-couchdb-plugin/README.md           |   194 -
 .../priv/default.d/my_first_couchdb_plugin.ini  |     3 -
 .../src/my_first_couchdb_plugin.app.src         |    21 -
 .../src/my_first_couchdb_plugin.erl             |    18 -
 .../test/my_first_couchdb_plugin_tests.erl      |    15 -
 src/snappy/Makefile.am                          |    78 -
 src/snappy/erl_nif_compat.h                     |   129 -
 src/snappy/google-snappy/AUTHORS                |     1 -
 src/snappy/google-snappy/COPYING                |    28 -
 src/snappy/google-snappy/config.h.in            |   125 -
 src/snappy/google-snappy/snappy-internal.h      |   150 -
 src/snappy/google-snappy/snappy-sinksource.cc   |    71 -
 src/snappy/google-snappy/snappy-sinksource.h    |   137 -
 .../google-snappy/snappy-stubs-internal.cc      |    42 -
 .../google-snappy/snappy-stubs-internal.h       |   571 -
 .../google-snappy/snappy-stubs-public.h.in      |    85 -
 src/snappy/google-snappy/snappy.cc              |  1111 --
 src/snappy/google-snappy/snappy.h               |   155 -
 src/snappy/snappy.app.in                        |    12 -
 src/snappy/snappy.erl                           |    56 -
 src/snappy/snappy_nif.cc                        |   265 -
 support/build_js.escript                        |    55 +
 test/Makefile.am                                |    15 -
 test/bench/Makefile.am                          |    22 -
 test/etap/001-load.t                            |    22 +-
 test/etap/002-icu-driver.t                      |     2 +-
 test/etap/010-file-basics.t                     |     1 +
 test/etap/022-emsort-basics.t                   |    72 +
 test/etap/030-doc-from-json.t                   |     4 +-
 test/etap/031-doc-to-json.t                     |     4 +-
 test/etap/041-uuid-gen-id.ini                   |    20 -
 test/etap/041-uuid-gen-seq.ini                  |    19 -
 test/etap/041-uuid-gen-utc.ini                  |    19 -
 test/etap/041-uuid-gen.t                        |    49 +-
 test/etap/070-couch-db.t                        |     5 +-
 test/etap/071-couchdb-rapid-cycle.t             |    74 +
 test/etap/072-cleanup.t                         |     6 +-
 test/etap/073-changes.t                         |   178 +-
 test/etap/074-doc-update-conflicts.t            |    36 +-
 test/etap/075-auth-cache.t                      |    22 +-
 test/etap/076-file-compression.t                |    29 +-
 test/etap/077-couch-db-fast-db-delete-create.t  |    27 +-
 test/etap/080-config-get-set.t                  |    38 +-
 test/etap/081-config-override.t                 |    48 +-
 test/etap/082-config-register.t                 |    63 +-
 test/etap/083-config-no-files.t                 |    12 +-
 test/etap/100-ref-counter.t                     |   114 -
 test/etap/121-stats-aggregates.t                |    13 +-
 test/etap/130-attachments-md5.t                 |     6 +-
 test/etap/140-attachment-comp.t                 |    10 +-
 test/etap/150-invalid-view-seq.t                |    21 +-
 test/etap/160-vhosts.t                          |    44 +-
 test/etap/170-os-daemons.t                      |    12 +-
 test/etap/171-os-daemons-config.es              |     2 +-
 test/etap/171-os-daemons-config.t               |     8 +-
 test/etap/172-os-daemon-errors.t                |     8 +-
 test/etap/173-os-daemon-cfg-register.t          |    10 +-
 test/etap/180-http-proxy.t                      |    16 +-
 test/etap/200-view-group-no-db-leaks.t          |   103 +-
 test/etap/201-view-group-shutdown.t             |    18 +-
 test/etap/210-os-proc-pool.t                    |     6 +-
 test/etap/220-compaction-daemon.t               |    18 +-
 test/etap/231-cors.t                            |    22 +-
 test/etap/Makefile.am                           |   109 -
 test/etap/etap.erl                              |   614 +
 test/etap/run.tpl                               |     2 +-
 test/etap/test_util.erl.in                      |    33 +-
 test/javascript/Makefile.am                     |    27 -
 test/javascript/cli_runner.js                   |     7 +-
 test/javascript/run                             |   131 +
 test/javascript/run.tpl                         |   138 -
 test/javascript/test_setup.js                   |     3 +-
 test/view_server/Makefile.am                    |    15 -
 utils/Makefile.am                               |    45 -
 var/Makefile.am                                 |    23 -
 667 files changed, 2996 insertions(+), 200705 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/couchdb/blob/65260510/.gitignore
----------------------------------------------------------------------
diff --cc .gitignore
index 0e39c34,f7d746d..ad9479d
--- a/.gitignore
+++ b/.gitignore
@@@ -1,142 -1,23 +1,22 @@@
- !.gitignore
- !.mailmap
- *.beam
- *.diff
- *.gz
- *.la
- *.lo
+ config.erl
+ install.mk
+ rel/*.config
+ rel/dev*
+ rel/tmpdata
+ src/
+ /log
+ 
  *.o
- *.orig
- *.pyc
- *.rej
- *.stamp
- *.sw*
- *.tpl
- *~
- .*
- INSTALL
- Makefile
- Makefile.in
- THANKS
- acinclude.m4
- aclocal.m4
- apache-couchdb-*
- autom4te.cache
- __pycache__
- bin/.deps/
- bin/couch-config
- bin/couch-config_dev
- bin/couchdb
- bin/couchdb.1
- bin/couchjs_dev
- bin/couchpw
- build-aux/config.*
- build-aux/depcomp
- build-aux/compile
- build-aux/install-sh
- build-aux/ltmain.sh
- build-aux/missing
- build-aux/texinfo.tex
- config.h
- config.h.in
- config.log
- config.status
- configure
- couchdb.stderr
- couchdb.stdout
- cover/*
- erl_crash.dump
- etc/couchdb/default.ini
- etc/couchdb/default_dev.ini
- etc/couchdb/local_dev.ini
- etc/init/couchdb
- etc/launchd/org.apache.couchdb.plist
- etc/logrotate.d/couchdb
- libtool
- m4
- share/doc/build/CouchDB.log
- share/doc/build/doctrees
- share/doc/build/html
- share/doc/build/latex
- share/doc/build/texinfo
+ *.so
+ ebin/
+ 
+ dev/boot_node.beam
+ dev/lib/
+ dev/logs/
+ 
  share/server/main-coffee.js
  share/server/main.js
- src/couch_mrview/ebin/
- src/couch_plugins/ebin/
- src/couch_replicator/ebin/
- src/couchdb/.deps/*
- src/couchdb/.libs/*
- src/couchdb/couch.app
- src/couchdb/couchjs
- src/couchdb/edoc-info
- src/couchdb/erlang.png
- src/couchdb/priv/.deps/
- src/couchdb/priv/.libs/
- src/couchdb/priv/couch_icu_driver.la
- src/couchdb/priv/couchjs
- src/couchdb/priv/couchjs.1
- src/couchdb/priv/couchspawnkillable
- src/couchdb/priv/stat_descriptions.cfg
- src/couchdb/priv/stat_descriptions.cfg
- src/couchdb/stylesheet.css
- src/ejson/.deps/
- src/ejson/.libs/
- src/ejson/ejson.app
- src/ejson/priv
- src/erlang-oauth/oauth.app
- src/erlang-oauth/oauth.app
- src/fauxton/node_modules
- src/fauxton/dist
- src/fauxton/build
- src/fauxton/app/load_addons.js
- !src/fauxton/app/addons/
- src/fauxton/app/addons/*
- !src/fauxton/app/addons/activetasks
- !src/fauxton/app/addons/config
- !src/fauxton/app/addons/plugins
- !src/fauxton/app/addons/logs
- !src/fauxton/app/addons/stats
- !src/fauxton/app/addons/replication
- !src/fauxton/app/addons/contribute
- !src/fauxton/app/addons/auth
- !src/fauxton/app/addons/exampleAuth
- !src/fauxton/app/addons/permissions
- !src/fauxton/app/addons/verifyinstall
- !src/fauxton/app/addons/compaction
- !src/fauxton/app/addons/fauxton
- !src/fauxton/app/addons/pouchdb
- !src/fauxton/app/addons/databases
- !src/fauxton/app/addons/documents
- !src/fauxton/app/addons/styletests
- src/fauxton/settings.json*
- !src/fauxton/settings.json.default
- !src/fauxton/assets/js/plugins/zeroclipboard/ZeroClipboard.swf
- src/ibrowse/ibrowse.app
- src/ibrowse/ibrowse.app
- src/mochiweb/mochiweb.app
- src/mochiweb/mochiweb.app
- !src/my-first-couchdb-plugin/.gitignore
- !src/my-first-couchdb-plugin/Makefile
- src/snappy/.deps/
- src/snappy/.libs/
- src/snappy/google-snappy/.deps/
- src/snappy/google-snappy/snappy-stubs-public.h
- src/snappy/google-snappy/stamp-h2
- src/snappy/priv
- src/snappy/snappy.app
- stamp-h1
- test/.deps/
- test/bench/run
- test/etap/.deps/
- test/etap/run
- test/etap/run
- test/etap/temp.*
- test/etap/test_cfg_register
- test/etap/test_util.erl
- test/javascript/run
- test/javascript/run_js_tests.sh
- test/local.ini
- tmp
- utils/run
- src/fauxton/test/test.config.js
- src/fauxton/app/initialize.js
+ 
+ src/couch/priv/couch_js/config.h
+ src/couch/priv/couchjs
+ src/couch/priv/couchspawnkillable
 -

http://git-wip-us.apache.org/repos/asf/couchdb/blob/65260510/.travis.yml
----------------------------------------------------------------------
diff --cc .travis.yml
index 1bddb6a,ba6eee8..d51b422
--- a/.travis.yml
+++ b/.travis.yml
@@@ -4,16 -4,13 +4,16 @@@ before_install
     - sudo apt-get -y install libtool automake autoconf autoconf-archive
     - sudo apt-get -y install texlive-latex-base texlive-latex-recommended
     - sudo apt-get -y install texlive-latex-extra texlive-fonts-recommended texinfo
 -   - sudo apt-get -y install python-pygments python-docutils python-sphinx 
 -before_script: ./bootstrap && ./configure
 -script: make distcheck
 +   - sudo apt-get -y install python-pygments python-docutils python-sphinx
- before_script: ./bootstrap && ./configure
++before_script: ./configure
 +script:
 +   - make distcheck
 +   - cd src/fauxton
 +   - npm install
 +   - grunt test
  language: erlang
  otp_release:
 -   - R15B02
 -   - R15B01
 -   - R15B
 +   - 17.0
 +   - R16B03-1
 +   - R15B03
     - R14B04
 -   - R14B03

http://git-wip-us.apache.org/repos/asf/couchdb/blob/65260510/LICENSE
----------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/couchdb/blob/65260510/license.skip
----------------------------------------------------------------------
diff --cc license.skip
index f5e49da,9c139ab..7b6ca04
--- a/license.skip
+++ b/license.skip
@@@ -80,14 -80,18 +87,24 @@@
  ^share/www/script/base64.js
  ^share/www/script/test/lorem.*
  ^share/www/style/jquery-ui-1.8.11.custom.css
 +^share/www/fauxton/img/.*
 +^share/www/fauxton/js/ace/mode-javascript.js
 +^share/www/fauxton/js/ace/mode-json.js
 +^share/www/fauxton/js/ace/theme-crimson_editor.js
 +^share/www/fauxton/js/ace/worker-javascript.js
 +^share/www/fauxton/js/ace/worker-json.js
  ^src/Makefile
  ^src/Makefile.in
+ ^src/chttpd/ebin/chttpd.app
+ ^src/config/ebin/config.app
+ ^src/couch/ebin/couch.app
+ ^src/couch/ebin/.*.beam
+ ^src/couch/priv/.*.so
+ ^src/couch/priv/couch_js/.*.o
+ ^src/couch/priv/icu_driver/.*.o
+ ^src/couch/priv/couchjs
+ ^src/couch/priv/couchspawnkillable
+ ^src/couch/priv/stat_descriptions.cfg
  ^src/couch_index/Makefile
  ^src/couch_index/Makefile.in
  ^src/couch_index/ebin/.*.beam
@@@ -94,75 -99,33 +112,91 @@@
  ^src/couch_mrview/Makefile
  ^src/couch_mrview/Makefile.in
  ^src/couch_mrview/ebin/.*.beam
+ ^src/couch_mrview/ebin/couch_mrview.app
 +^src/couch_plugins/README.md
 +^src/couch_plugins/Makefile
 +^src/couch_plugins/Makefile.in
 +^src/couch_plugins/ebin/.*.beam
  ^src/couch_replicator/Makefile
  ^src/couch_replicator/Makefile.in
+ ^src/couch_replicator/README.md
  ^src/couch_replicator/ebin/.*.beam
- ^src/couchdb/.*.beam
- ^src/couchdb/.deps/.*
- ^src/couchdb/Makefile
- ^src/couchdb/Makefile.in
- ^src/couchdb/couch.app.*
- ^src/couchdb/priv/.*.o
- ^src/couchdb/priv/.deps/.*
- ^src/couchdb/priv/Makefile
- ^src/couchdb/priv/Makefile.in
- ^src/couchdb/priv/couch_icu_driver.la
- ^src/couchdb/priv/couchjs
- ^src/couchdb/priv/couchspawnkillable
- ^src/couchdb/priv/stat_descriptions.cfg
- ^src/couchdb/priv/icu_driver/.deps/.dirstamp
- ^src/couchdb/priv/icu_driver/.dirstamp
++^src/couch/.*.beam
++^src/couch/.deps/.*
++^src/couch/Makefile
++^src/couch/Makefile.in
++^src/couch/couch.app.*
++^src/couch/priv/.*.o
++^src/couch/priv/.deps/.*
++^src/couch/priv/Makefile
++^src/couch/priv/Makefile.in
++^src/couch/priv/couch_icu_driver.la
++^src/couch/priv/couchjs
++^src/couch/priv/couchspawnkillable
++^src/couch/priv/stat_descriptions.cfg
++^src/couch/priv/icu_driver/.deps/.dirstamp
++^src/couch/priv/icu_driver/.dirstamp
 +^src/couchjs-node/package.json
 +^src/couchjs-node/sandbox.js
 +^src/couchjs-node/README.md
 +^src/couchjs-node/Makefile
 +^src/couchjs-node/Makefile.in
 +^src/erlang-oauth/.*
 +^src/couch_dbupdates
 +^src/ejson/.*
 +^src/etap/.*
 +^src/fauxton/app/addons/config/assets/less/config.less
 +^src/fauxton/assets/css/codemirror.css
 +^src/fauxton/assets/css/nv.d3.css
 +^src/fauxton/assets/img/.*
 +^src/fauxton/assets/js/libs/.*.js
 +^src/fauxton/assets/js/libs/ace/.*.js
 +^src/fauxton/assets/js/libs/ace/snippets/.*.js
 +^src/fauxton/assets/js/plugins/.*.js
 +^src/fauxton/assets/js/plugins/zeroclipboard/ZeroClipboard.swf
 +^src/fauxton/assets/less/bootstrap/.*.less
 +^src/fauxton/assets/less/bootstrap/tests/css-tests.css
 +^src/fauxton/assets/less/bootstrap/tests/buttons.html
 +^src/fauxton/favicon.ico
 +^src/fauxton/package.json
 +^src/fauxton/extensions.md
 +^src/fauxton/readme.md
 +^src/fauxton/writing_addons.md
 +^src/fauxton/TODO.md
 +^src/fauxton/CONTRIBUTING.md
 +^src/fauxton/settings.json.*
 +^src/fauxton/test/test.config.underscore
 +^src/fauxton/test/mocha/chai.js
 +^src/fauxton/test/mocha/mocha.css
 +^src/fauxton/test/mocha/mocha.js
 +^src/fauxton/test/mocha/sinon.js
 +^src/fauxton/test/mocha/sinon-chai.js
 +^src/fauxton/tasks/addon/rename.json
 +^src/fauxton/assets/lib/ace/.*
 +^src/fauxton/app/addons/pouchdb/pouch.collate.js
 +^src/fauxton/app/addons/pouchdb/pouchdb.mapreduce.js
+ ^src/couch_replicator/ebin/couch_replicator.app
+ ^src/ddoc_cache/ebin/ddoc_cache.app
+ ^src/ddoc_cache/README.md
+ ^src/ets_lru/ebin/.*.beam
+ ^src/ets_lru/ebin/ets_lru.app
+ ^src/ets_lru/test/etap.erl
+ ^src/ejson/.*
+ ^src/etap/.*
+ ^src/fabric/ebin/.*.beam
+ ^src/fabric/ebin/fabric.app
  ^src/ibrowse/.*
+ ^src/jiffy/.*
+ ^src/mem3/ebin/mem3.app
  ^src/mochiweb/.*
- ^src/my-first-couchdb-plugin/priv/*/*
- ^src/my-first-couchdb-plugin/README.md
- ^src/my-first-couchdb-plugin/.gitignore
- ^src/my-first-couchdb-plugin/Makefile
- ^src/my-first-couchdb-plugin/Makefile.in
+ ^src/rexi/ebin/.*.beam
+ ^src/rexi/ebin/rexi.app
  ^src/snappy/.*
+ ^src/twig/ebin/.*.beam
+ ^src/twig/ebin/twig.app
+ ^src/twig/README.md
+ ^src/twig/src/trunc_io.erl
+ ^src/oauth/.*
  ^stamp-h1
  ^test/Makefile
  ^test/Makefile.in

http://git-wip-us.apache.org/repos/asf/couchdb/blob/65260510/rel/overlay/etc/default.ini
----------------------------------------------------------------------
diff --cc rel/overlay/etc/default.ini
index 0000000,19052db..dfcd3bc
mode 000000,100644..100644
--- a/rel/overlay/etc/default.ini
+++ b/rel/overlay/etc/default.ini
@@@ -1,0 -1,362 +1,373 @@@
+ ; Upgrading CouchDB will overwrite this file.
+ [vendor]
+ name = {{package_author_name}}
+ 
+ [couchdb]
+ database_dir = {{data_dir}}
+ view_index_dir = {{view_index_dir}}
+ ; util_driver_dir =
++; plugin_dir =
+ max_document_size = 67108864 ; 64 MB
+ os_process_timeout = 5000 ; 5 seconds. for view and external servers.
+ max_dbs_open = 500
+ delayed_commits = false
+ ; Method used to compress everything that is appended to database and view index files, except
+ ; for attachments (see the attachments section). Available methods are:
+ ;
+ ; none         - no compression
+ ; snappy       - use google snappy, a very fast compressor/decompressor
+ ; deflate_[N]  - use zlib's deflate, N is the compression level which ranges from 1 (fastest,
+ ;                lowest compression ratio) to 9 (slowest, highest compression ratio)
+ file_compression = snappy
+ ; Higher values may give better read performance due to less read operations
+ ; and/or more OS page cache hits, but they can also increase overall response
+ ; time for writes when there are many attachment write requests in parallel.
+ attachment_stream_buffer_size = 4096
+ 
+ [cluster]
+ q=8
+ r=2
+ w=2
+ n=3
+ 
+ [chttpd]
+ port = {{cluster_port}}
+ backlog = 512
+ docroot = {{prefix}}/share/www
+ 
+ [database_compaction]
+ ; larger buffer sizes can originate smaller files
+ doc_buffer_size = 524288 ; value in bytes
+ checkpoint_after = 5242880 ; checkpoint after every N bytes were written
+ 
+ [view_compaction]
+ ; larger buffer sizes can originate smaller files
+ keyvalue_buffer_size = 2097152 ; value in bytes
+ 
+ [httpd]
+ port = {{backend_port}}
+ bind_address = 127.0.0.1
+ authentication_handlers = {couch_httpd_oauth, oauth_authentication_handler}, {couch_httpd_auth, cookie_authentication_handler}, {couch_httpd_auth, default_authentication_handler}
+ default_handler = {couch_httpd_db, handle_request}
+ secure_rewrites = true
+ vhost_global_handlers = _utils, _uuids, _session, _oauth, _users
+ allow_jsonp = false
+ ; Options for the MochiWeb HTTP server.
+ ;server_options = [{backlog, 128}, {acceptor_pool_size, 16}]
+ ; For more socket options, consult Erlang's module 'inet' man page.
+ ;socket_options = [{recbuf, 262144}, {sndbuf, 262144}, {nodelay, true}]
++socket_options = [{recbuf, 262144}, {sndbuf, 262144}]
+ log_max_chunk_size = 1000000
+ enable_cors = false
++; CouchDB can optionally enforce a maximum uri length;
++; max_uri_length = 8000
+ 
+ [ssl]
+ port = 6984
+ 
+ [couch_httpd_auth]
+ authentication_db = _users
+ authentication_redirect = /_utils/session.html
+ require_valid_user = false
+ timeout = 600 ; number of seconds before automatic logout
+ auth_cache_size = 50 ; size is number of cache entries
+ allow_persistent_cookies = false ; set to true to allow persistent cookies
 -iterations = 10000 ; iterations for password hashing
++iterations = 10 ; iterations for password hashing
+ ; min_iterations = 1
+ ; max_iterations = 1000000000
+ 
++; comma-separated list of public fields, 404 if empty
++; public_fields =
++
+ ; Experimental CSP (Content Security Policy) Support for _utils
+ [csp]
+ enable = false
+ ; header_value = default-src 'self'; img-src 'self'; font-src *; script-src 'self' 'unsafe-eval'; style-src 'self' 'unsafe-inline';
+ 
+ [cors]
+ credentials = false
+ ; List of origins separated by a comma, * means accept all
+ ; Origins must include the scheme: http://example.com
+ ; You can’t set origins: * and credentials = true at the same time.
+ ;origins = *
+ ; List of accepted headers separated by a comma
+ ; headers =
+ ; List of accepted methods
+ ; methods =
+ 
++; Experimental CSP (Content Security Policy) Support for _utils
++[csp]
++enable = false
++; header_value = default-src 'self'; img-src 'self'; font-src *; script-src 'self' 'unsafe-eval'; style-src 'self' 'unsafe-inline';
+ 
+ ; Configuration for a vhost
+ ;[cors:http://example.com]
+ ; credentials = false
+ ; List of origins separated by a comma
+ ; Origins must include the scheme: http://example.com
+ ; You can’t set origins: * and credentials = true at the same time.
+ ;origins =
+ ; List of accepted headers separated by a comma
+ ; headers =
+ ; List of accepted methods
+ ; methods =
+ 
+ [couch_httpd_oauth]
+ ; If set to 'true', oauth token and consumer secrets will be looked up
+ ; in the authentication database (_users). These secrets are stored in
+ ; a top level property named "oauth" in user documents. Example:
+ ;     {
+ ;         "_id": "org.couchdb.user:joe",
+ ;         "type": "user",
+ ;         "name": "joe",
+ ;         "password_sha": "fe95df1ca59a9b567bdca5cbaf8412abd6e06121",
+ ;         "salt": "4e170ffeb6f34daecfd814dfb4001a73"
+ ;         "roles": ["foo", "bar"],
+ ;         "oauth": {
+ ;             "consumer_keys": {
+ ;                 "consumerKey1": "key1Secret",
+ ;                 "consumerKey2": "key2Secret"
+ ;             },
+ ;             "tokens": {
+ ;                 "token1": "token1Secret",
+ ;                 "token2": "token2Secret"
+ ;             }
+ ;         }
+ ;     }
+ use_users_db = false
+ 
+ [query_servers]
+ javascript = {{prefix}}/bin/couchjs {{prefix}}/share/server/main.js
+ coffeescript = {{prefix}}/bin/couchjs {{prefix}}/share/server/main-coffee.js
+ 
+ 
+ ; Changing reduce_limit to false will disable reduce_limit.
+ ; If you think you're hitting reduce_limit with a "good" reduce function,
+ ; please let us know on the mailing list so we can fine tune the heuristic.
+ [query_server_config]
+ reduce_limit = true
+ os_process_limit = 25
+ 
+ [daemons]
+ index_server={couch_index_server, start_link, []}
+ external_manager={couch_external_manager, start_link, []}
+ query_servers={couch_proc_manager, start_link, []}
+ vhosts={couch_httpd_vhost, start_link, []}
+ httpd={couch_httpd, start_link, []}
+ stats_aggregator={couch_stats_aggregator, start, []}
+ stats_collector={couch_stats_collector, start, []}
+ uuids={couch_uuids, start, []}
+ auth_cache={couch_auth_cache, start_link, []}
+ replicator_manager={couch_replicator_manager, start_link, []}
+ os_daemons={couch_os_daemons, start_link, []}
+ compaction_daemon={couch_compaction_daemon, start_link, []}
+ 
+ [indexers]
+ couch_mrview = true
+ 
+ [httpd_global_handlers]
+ / = {couch_httpd_misc_handlers, handle_welcome_req, <<"Welcome">>}
+ favicon.ico = {couch_httpd_misc_handlers, handle_favicon_req, "{{prefix}}/share/www"}
+ 
+ _utils = {couch_httpd_misc_handlers, handle_utils_dir_req, "{{prefix}}/share/www"}
+ _all_dbs = {couch_httpd_misc_handlers, handle_all_dbs_req}
+ _active_tasks = {couch_httpd_misc_handlers, handle_task_status_req}
+ _config = {couch_httpd_misc_handlers, handle_config_req}
+ _replicate = {couch_replicator_httpd, handle_req}
+ _uuids = {couch_httpd_misc_handlers, handle_uuids_req}
+ _restart = {couch_httpd_misc_handlers, handle_restart_req}
+ _stats = {couch_httpd_stats_handlers, handle_stats_req}
+ _session = {couch_httpd_auth, handle_session_req}
+ _oauth = {couch_httpd_oauth, handle_oauth_req}
+ _db_updates = {couch_dbupdates_httpd, handle_req}
+ _plugins = {couch_plugins_httpd, handle_req}
+ 
+ [httpd_db_handlers]
+ _all_docs = {couch_mrview_http, handle_all_docs_req}
+ _changes = {couch_httpd_db, handle_changes_req}
+ _compact = {couch_httpd_db, handle_compact_req}
+ _design = {couch_httpd_db, handle_design_req}
+ _temp_view = {couch_mrview_http, handle_temp_view_req}
+ _view_cleanup = {couch_mrview_http, handle_cleanup_req}
+ 
+ ; The external module takes an optional argument allowing you to narrow it to a
+ ; single script. Otherwise the script name is inferred from the first path section
+ ; after _external's own path.
+ ; _mypath = {couch_httpd_external, handle_external_req, <<"mykey">>}
+ ; _external = {couch_httpd_external, handle_external_req}
+ 
+ [httpd_design_handlers]
+ _compact = {couch_mrview_http, handle_compact_req}
+ _info = {couch_mrview_http, handle_info_req}
+ _list = {couch_mrview_show, handle_view_list_req}
+ _rewrite = {couch_httpd_rewrite, handle_rewrite_req}
+ _show = {couch_mrview_show, handle_doc_show_req}
+ _update = {couch_mrview_show, handle_doc_update_req}
+ _view = {couch_mrview_http, handle_view_req}
+ 
+ ; enable external as an httpd handler, then link it with commands here.
+ ; note, this api is still under consideration.
+ ; [external]
+ ; mykey = /path/to/mycommand
+ 
+ ; Here you can setup commands for CouchDB to manage
+ ; while it is alive. It will attempt to keep each command
+ ; alive if it exits.
+ ; [os_daemons]
+ ; some_daemon_name = /path/to/script -with args
+ 
+ 
+ [uuids]
+ ; Known algorithms:
+ ;   random - 128 bits of random awesome
+ ;     All awesome, all the time.
+ ;   sequential - monotonically increasing ids with random increments
+ ;     First 26 hex characters are random. Last 6 increment in
+ ;     random amounts until an overflow occurs. On overflow, the
+ ;     random prefix is regenerated and the process starts over.
+ ;   utc_random - Time since Jan 1, 1970 UTC with microseconds
+ ;     First 14 characters are the time in hex. Last 18 are random.
+ ;   utc_id - Time since Jan 1, 1970 UTC with microseconds, plus utc_id_suffix string
+ ;     First 14 characters are the time in hex. uuids/utc_id_suffix string value is appended to these.
+ algorithm = sequential
+ ; The utc_id_suffix value will be appended to uuids generated by the utc_id algorithm.
+ ; Replicating instances should have unique utc_id_suffix values to ensure uniqueness of utc_id ids.
+ utc_id_suffix =
+ # Maximum number of UUIDs retrievable from /_uuids in a single request
+ max_count = 1000
+ 
+ [stats]
+ ; rate is in milliseconds
+ rate = 1000
+ ; sample intervals are in seconds
+ samples = [0, 60, 300, 900]
+ 
+ [attachments]
+ compression_level = 8 ; from 1 (lowest, fastest) to 9 (highest, slowest), 0 to disable compression
+ compressible_types = text/*, application/javascript, application/json, application/xml
+ 
+ [replicator]
+ db = _replicator
+ ; Maximum replicaton retry count can be a non-negative integer or "infinity".
+ max_replication_retry_count = 10
+ ; More worker processes can give higher network throughput but can also
+ ; imply more disk and network IO.
+ worker_processes = 4
+ ; With lower batch sizes checkpoints are done more frequently. Lower batch sizes
+ ; also reduce the total amount of used RAM memory.
+ worker_batch_size = 500
+ ; Maximum number of HTTP connections per replication.
+ http_connections = 20
+ ; HTTP connection timeout per replication.
+ ; Even for very fast/reliable networks it might need to be increased if a remote
+ ; database is too busy.
+ connection_timeout = 30000
+ ; If a request fails, the replicator will retry it up to N times.
+ retries_per_request = 10
+ ; Some socket options that might boost performance in some scenarios:
+ ;       {nodelay, boolean()}
+ ;       {sndbuf, integer()}
+ ;       {recbuf, integer()}
+ ;       {priority, integer()}
+ ; See the `inet` Erlang module's man page for the full list of options.
+ socket_options = [{keepalive, true}, {nodelay, false}]
+ ; Path to a file containing the user's certificate.
+ ;cert_file = /full/path/to/server_cert.pem
+ ; Path to file containing user's private PEM encoded key.
+ ;key_file = /full/path/to/server_key.pem
+ ; String containing the user's password. Only used if the private keyfile is password protected.
+ ;password = somepassword
+ ; Set to true to validate peer certificates.
+ verify_ssl_certificates = false
+ ; File containing a list of peer trusted certificates (in the PEM format).
+ ;ssl_trusted_certificates_file = /etc/ssl/certs/ca-certificates.crt
+ ; Maximum peer certificate depth (must be set even if certificate validation is off).
+ ssl_certificate_max_depth = 3
+ 
+ [compaction_daemon]
+ ; The delay, in seconds, between each check for which database and view indexes
+ ; need to be compacted.
+ check_interval = 300
+ ; If a database or view index file is smaller then this value (in bytes),
+ ; compaction will not happen. Very small files always have a very high
+ ; fragmentation therefore it's not worth to compact them.
+ min_file_size = 131072
+ 
+ [compactions]
+ ; List of compaction rules for the compaction daemon.
+ ; The daemon compacts databases and their respective view groups when all the
+ ; condition parameters are satisfied. Configuration can be per database or
+ ; global, and it has the following format:
+ ;
+ ; database_name = [ {ParamName, ParamValue}, {ParamName, ParamValue}, ... ]
+ ; _default = [ {ParamName, ParamValue}, {ParamName, ParamValue}, ... ]
+ ;
+ ; Possible parameters:
+ ;
+ ; * db_fragmentation - If the ratio (as an integer percentage), of the amount
+ ;                      of old data (and its supporting metadata) over the database
+ ;                      file size is equal to or greater then this value, this
+ ;                      database compaction condition is satisfied.
+ ;                      This value is computed as:
+ ;
+ ;                           (file_size - data_size) / file_size * 100
+ ;
+ ;                      The data_size and file_size values can be obtained when
+ ;                      querying a database's information URI (GET /dbname/).
+ ;
+ ; * view_fragmentation - If the ratio (as an integer percentage), of the amount
+ ;                        of old data (and its supporting metadata) over the view
+ ;                        index (view group) file size is equal to or greater then
+ ;                        this value, then this view index compaction condition is
+ ;                        satisfied. This value is computed as:
+ ;
+ ;                            (file_size - data_size) / file_size * 100
+ ;
+ ;                        The data_size and file_size values can be obtained when
+ ;                        querying a view group's information URI
+ ;                        (GET /dbname/_design/groupname/_info).
+ ;
+ ; * from _and_ to - The period for which a database (and its view groups) compaction
+ ;                   is allowed. The value for these parameters must obey the format:
+ ;
+ ;                   HH:MM - HH:MM  (HH in [0..23], MM in [0..59])
+ ;
+ ; * strict_window - If a compaction is still running after the end of the allowed
+ ;                   period, it will be canceled if this parameter is set to 'true'.
+ ;                   It defaults to 'false' and it's meaningful only if the *period*
+ ;                   parameter is also specified.
+ ;
+ ; * parallel_view_compaction - If set to 'true', the database and its views are
+ ;                              compacted in parallel. This is only useful on
+ ;                              certain setups, like for example when the database
+ ;                              and view index directories point to different
+ ;                              disks. It defaults to 'false'.
+ ;
+ ; Before a compaction is triggered, an estimation of how much free disk space is
+ ; needed is computed. This estimation corresponds to 2 times the data size of
+ ; the database or view index. When there's not enough free disk space to compact
+ ; a particular database or view index, a warning message is logged.
+ ;
+ ; Examples:
+ ;
+ ; 1) [{db_fragmentation, "70%"}, {view_fragmentation, "60%"}]
+ ;    The `foo` database is compacted if its fragmentation is 70% or more.
+ ;    Any view index of this database is compacted only if its fragmentation
+ ;    is 60% or more.
+ ;
+ ; 2) [{db_fragmentation, "70%"}, {view_fragmentation, "60%"}, {from, "00:00"}, {to, "04:00"}]
+ ;    Similar to the preceding example but a compaction (database or view index)
+ ;    is only triggered if the current time is between midnight and 4 AM.
+ ;
+ ; 3) [{db_fragmentation, "70%"}, {view_fragmentation, "60%"}, {from, "00:00"}, {to, "04:00"}, {strict_window, true}]
+ ;    Similar to the preceding example - a compaction (database or view index)
+ ;    is only triggered if the current time is between midnight and 4 AM. If at
+ ;    4 AM the database or one of its views is still compacting, the compaction
+ ;    process will be canceled.
+ ;
+ ; 4) [{db_fragmentation, "70%"}, {view_fragmentation, "60%"}, {from, "00:00"}, {to, "04:00"}, {strict_window, true}, {parallel_view_compaction, true}]
+ ;    Similar to the preceding example, but a database and its views can be
+ ;    compacted in parallel.
+ ;
+ ;_default = [{db_fragmentation, "70%"}, {view_fragmentation, "60%"}, {from, "23:00"}, {to, "04:00"}]
+ 

http://git-wip-us.apache.org/repos/asf/couchdb/blob/65260510/rel/overlay/etc/local.ini
----------------------------------------------------------------------
diff --cc rel/overlay/etc/local.ini
index 0000000,0fc8433..dfd5d67
mode 000000,100644..100644
--- a/rel/overlay/etc/local.ini
+++ b/rel/overlay/etc/local.ini
@@@ -1,0 -1,83 +1,98 @@@
+ ; CouchDB Configuration Settings
+ 
+ ; Custom settings should be made in this file. They will override settings
+ ; in default.ini, but unlike changes made to default.ini, this file won't be
+ ; overwritten on server upgrade.
+ 
+ [couchdb]
+ ;max_document_size = 4294967296 ; bytes
+ 
+ [httpd]
+ ;port = 5984
+ ;bind_address = 127.0.0.1
+ ; Options for the MochiWeb HTTP server.
+ ;server_options = [{backlog, 128}, {acceptor_pool_size, 16}]
+ ; For more socket options, consult Erlang's module 'inet' man page.
+ ;socket_options = [{recbuf, 262144}, {sndbuf, 262144}, {nodelay, true}]
+ 
+ ; Uncomment next line to trigger basic-auth popup on unauthorized requests.
+ ;WWW-Authenticate = Basic realm="administrator"
+ 
+ ; Uncomment next line to set the configuration modification whitelist. Only
+ ; whitelisted values may be changed via the /_config URLs. To allow the admin
+ ; to change this value over HTTP, remember to include {httpd,config_whitelist}
+ ; itself. Excluding it from the list would require editing this file to update
+ ; the whitelist.
+ ;config_whitelist = [{httpd,config_whitelist}, {log,level}, {etc,etc}]
+ 
++[query_servers]
++;nodejs = /usr/local/bin/couchjs-node /path/to/couchdb/share/server/main.js
++
++
+ [httpd_global_handlers]
+ ;_google = {couch_httpd_proxy, handle_proxy_req, <<"http://www.google.com">>}
+ 
+ [couch_httpd_auth]
+ ; If you set this to true, you should also uncomment the WWW-Authenticate line
+ ; above. If you don't configure a WWW-Authenticate header, CouchDB will send
+ ; Basic realm="server" in order to prevent you getting logged out.
+ ; require_valid_user = false
+ 
+ [os_daemons]
+ ; For any commands listed here, CouchDB will attempt to ensure that
+ ; the process remains alive. Daemons should monitor their environment
+ ; to know when to exit. This can most easily be accomplished by exiting
+ ; when stdin is closed.
+ ;foo = /path/to/command -with args
+ 
+ [daemons]
+ ; enable SSL support by uncommenting the following line and supply the PEM's below.
+ ; the default ssl port CouchDB listens on is 6984
+ ; httpsd = {couch_httpd, start_link, [https]}
+ 
+ [ssl]
+ ;cert_file = /full/path/to/server_cert.pem
+ ;key_file = /full/path/to/server_key.pem
+ ;password = somepassword
+ ; set to true to validate peer certificates
+ ;verify_ssl_certificates = false
++; Set to true to fail if the client does not send a certificate. Only used if verify_ssl_certificates is true.
++;fail_if_no_peer_cert = false
+ ; Path to file containing PEM encoded CA certificates (trusted
+ ; certificates used for verifying a peer certificate). May be omitted if
+ ; you do not want to verify the peer.
+ ;cacert_file = /full/path/to/cacertf
+ ; The verification fun (optional) if not specified, the default
+ ; verification fun will be used.
+ ;verify_fun = {Module, VerifyFun}
+ ; maximum peer certificate depth
+ ;ssl_certificate_max_depth = 1
++;
++; Reject renegotiations that do not live up to RFC 5746.
++;secure_renegotiate = true
++; The cipher suites that should be supported.
++; Can be specified in erlang format "{ecdhe_ecdsa,aes_128_cbc,sha256}"
++; or in OpenSSL format "ECDHE-ECDSA-AES128-SHA256".
++;ciphers = ["ECDHE-ECDSA-AES128-SHA256", "ECDHE-ECDSA-AES128-SHA"]
++; The SSL/TLS versions to support
++;tls_versions = [sslv3, tlsv1, 'tlsv1.1', 'tlsv1.2']
+ 
+ ; To enable Virtual Hosts in CouchDB, add a vhost = path directive. All requests to
+ ; the Virual Host will be redirected to the path. In the example below all requests
+ ; to http://example.com/ are redirected to /database.
+ ; If you run CouchDB on a specific port, include the port number in the vhost:
+ ; example.com:5984 = /database
+ [vhosts]
+ ;example.com = /database/
+ 
+ [update_notification]
+ ;unique notifier name=/full/path/to/exe -with "cmd line arg"
+ 
+ ; To create an admin account uncomment the '[admins]' section below and add a
+ ; line in the format 'username = password'. When you next start CouchDB, it
+ ; will change the password to a hash (so that your passwords don't linger
+ ; around in plain-text files). You can add more admin accounts with more
+ ; 'username = password' lines. Don't forget to restart CouchDB after
+ ; changing this.
+ [admins]
+ ;admin = mysecretpassword

http://git-wip-us.apache.org/repos/asf/couchdb/blob/65260510/share/server/loop.js
----------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/couchdb/blob/65260510/share/server/util.js
----------------------------------------------------------------------
diff --cc test/etap/072-cleanup.t
index 9cbcdfa,4792377..ddd8ca8
--- a/test/etap/072-cleanup.t
+++ b/test/etap/072-cleanup.t
@@@ -121,6 -121,6 +121,6 @@@ view_cleanup() -
  
  count_index_files() ->
      % call server to fetch the index files
-     RootDir = couch_config:get("couchdb", "view_index_dir"),
 -    RootDir = config:get("couchdb", "index_dir"),
++    RootDir = config:get("couchdb", "view_index_dir"),
      length(filelib:wildcard(RootDir ++ "/." ++
          binary_to_list(?TEST_DB) ++ "_design"++"/mrview/*")).

http://git-wip-us.apache.org/repos/asf/couchdb/blob/65260510/test/etap/073-changes.t
----------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/couchdb/blob/65260510/test/etap/075-auth-cache.t
----------------------------------------------------------------------
diff --cc test/etap/075-auth-cache.t
index 623884b,1c8b181..4d79134
--- a/test/etap/075-auth-cache.t
+++ b/test/etap/075-auth-cache.t
@@@ -67,13 -65,11 +65,13 @@@ main(_) -
  
  
  test() ->
-     couch_server_sup:start_link(test_util:config_files()),
-     OrigName = couch_config:get("couch_httpd_auth", "authentication_db"),
-     couch_config:set(
+     test_util:start_couch(),
+     OrigName = config:get("couch_httpd_auth", "authentication_db"),
+     config:set(
          "couch_httpd_auth", "authentication_db",
          binary_to_list(auth_db_name()), false),
 +    delete_db(auth_db_name()),
 +    delete_db(auth_db_2_name()),
  
      test_auth_db_crash(),
  

http://git-wip-us.apache.org/repos/asf/couchdb/blob/65260510/test/etap/140-attachment-comp.t
----------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/couchdb/blob/65260510/test/etap/231-cors.t
----------------------------------------------------------------------
diff --cc test/etap/231-cors.t
index 2f420d1,8e13c42..0eb0252
--- a/test/etap/231-cors.t
+++ b/test/etap/231-cors.t
@@@ -58,8 -58,12 +58,8 @@@ cycle_db(DbName) -
      Db.
  
  test() ->
 -
 -    ibrowse:start(),
 -    crypto:start(),
 -
      %% launch couchdb
-     couch_server_sup:start_link(test_util:config_files()),
+     ok = test_util:start_couch(),
  
      %% initialize db
      timer:sleep(1000),
@@@ -87,18 -89,18 +87,18 @@@
      test_db1_origin_request(),
      test_preflight_with_port1(),
      test_preflight_with_scheme1(),
 +    test_if_none_match_header(),
  
-     ok = couch_config:set("cors", "origins", "http://example.com:5984", false),
+     ok = config:set("cors", "origins", "http://example.com:5984", false),
      test_preflight_with_port2(),
  
-     ok = couch_config:set("cors", "origins", "https://example.com:5984", false),
+     ok = config:set("cors", "origins", "https://example.com:5984", false),
      test_preflight_with_scheme2(),
  
-     ok = couch_config:set("cors", "origins", "*", false),
+     ok = config:set("cors", "origins", "*", false),
      test_preflight_with_wildcard(),
  
-     ok = couch_config:set("cors", "origins", "http://example.com", false),
+     ok = config:set("cors", "origins", "http://example.com", false),
      test_case_sensitive_mismatch_of_allowed_origins(),
  
      % http://www.w3.org/TR/cors/#supports-credentials
diff --cc share/server/util.js
index 6857132,37b75c2..9e49970
--- a/share/server/util.js
+++ b/share/server/util.js
@@@ -141,13 -129,13 +138,13 @@@ var Couch = 
    }
  };
  
  // prints the object as JSON, and rescues and logs any toJSON() related errors
  function respond(obj) {
    try {
-     print(Couch.toJSON(obj));
+     print(JSON.stringify(obj));
    } catch(e) {
      log("Error converting object to JSON: " + e.toString());
 -    log("error on obj: "+ obj.toSource());
 +    log("error on obj: "+ (obj.toSource ? obj.toSource() : obj.toString()));
    }
  };
  

http://git-wip-us.apache.org/repos/asf/couchdb/blob/65260510/share/server/views.js
----------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/couchdb/blob/65260510/share/www/script/futon.browse.js
----------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/couchdb/blob/65260510/share/www/script/test/show_documents.js
----------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/couchdb/blob/65260510/share/www/script/test/users_db_security.js
----------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/couchdb/blob/65260510/test/etap/072-cleanup.t
----------------------------------------------------------------------
@@@ -141,13 -129,13 +138,13 @@@ var Couch = 
  };
  
- // prints the object as JSON, and rescues and logs any toJSON() related errors
+ // prints the object as JSON, and rescues and logs any JSON.stringify() related errors
  function respond(obj) {
    try {